#
# spec file for package python-QtAwesome
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define skip_python2 1
Name:           python-QtAwesome
Version:        1.2.1
Release:        2.1
Summary:        FontAwesome icons in PyQt and PySide applications
License:        MIT
URL:            https://github.com/spyder-ide/qtawesome
Source:         https://files.pythonhosted.org/packages/source/Q/QtAwesome/QtAwesome-%{version}.tar.gz
BuildRequires:  %{python_module QtPy}
BuildRequires:  %{python_module setuptools}
# SECTION test requirements
BuildRequires:  %{python_module pytest-qt}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module pytest}
# Choose one of the many backend options for pytest-qt,
# only PyQt5 available for all flavors and supported by QtPy
BuildRequires:  %{python_module qt5}
# /SECTION
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-QtPy
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
QtAwesome enables iconic fonts such as Font Awesome and
Elusive Icons in PyQt and PySide applications.

It is a port to Python - PyQt / PySide of the QtAwesome C++
library by Rick Blommers.

%prep
%setup -q -n QtAwesome-%{version}
dos2unix CHANGELOG.md README.md

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/qta-browser

%check
%pytest -v qtawesome/tests

%post
%python_install_alternative qta-browser

%postun
%python_uninstall_alternative qta-browser

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.md README.md
%{python_sitelib}/*
%python_alternative %{_bindir}/qta-browser

%changelog
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Oct 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.2.1
  Issues Closed
  * Issue 214 - Regression with 1.2 on Windows (PR 215 by @dalthviz)
  * Issue 212 - Release QtAwesome 1.2.1
  * Issue 210 - QtAwesome 1.2.0 incompatible with PySide2 (PR 211 by @dalthviz)
  In this release 3 issues were closed.
  Pull Requests Merged
  * PR 215 - PR: Handle per user font installation failing due to missing/not available registry keys, by @dalthviz (214)
  * PR 211 - PR: Handle PySide2 not having QtGui.QGlyphRun and add tests jobs with PySide2, by @dalthviz (210)
  In this release 2 pull requests were closed.
- Update to 1.2.0
  Full changelog https://github.com/spyder-ide/qtawesome/blob/master/CHANGELOG.md#version-120-2022-10-19
* Mon Aug 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.1.1
  * Change to "Ctrl+F" because PyQt6 doesn't support Modifier + Key by @kumattau in #183
  * Update README docs badge, Copyright year and sponsors logo by @dalthviz in #184
  * Add DeprecationWarning for FontAwesome 4.7 icon set by @dalthviz in #185
  * Try calling newer Qt methods first before falling back to deprecated/removed ones by @kumattau in #186
* Sat Oct 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.0.3
  * Fix: Implicit integer conversion is deprecated,
    Cast tileWidth to an integer
  * Fix: Timer should belong to parent widget
- Resolve have-choice for Qt backends tested by pytest-qt
* Tue Feb  9 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.0.2
  * Perform a font id validation
  * Add entries to the mdi charmap to be supported by Spyder
    <= 4.1.5 (1.0.1)
  * Update Material design icons to 5.4.55 (1.0.0)
  * Drop Python 2 support (1.0.0)
  * Fix deprecation warnings  due to invalid escape sequences
    (0.7.3)
- Use pytest-xvfb -- much more stable than the xvfb-run in sequence
  for each python flavor
* Tue Jul 28 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.7.2:
  * Update release instructions for the 0.x branch, by @ccordoba12
  * Do not call python directly in tests, by @scarabeusiv
  * Remove warning for Python 2.7, by @dalthviz (140)
  * al design icons to 4.9.95
  * t class to display icons as widgets
  * rowser
  * Fix file lock (125)
  * Update documentation and images (45)
  * Use Github as the only CI provider
  * Update MDI to 4.9.95
  * Add IconWidget to display icon as widget
  * Add an icon browser
  * Improve sponsors section in readme
  * Replace QtGui by QtWidgets in docs
  * Update MDI to 4.5.95
  * Update number of icons in Readme and docs
- Drop no-py2.patch, merged upstream.
- Add update-alternatives for new qta-browser binary
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to not call python2:
  * no-py2.patch
* Mon Jul 29 2019 pgajdos@suse.com
- version update to 0.6.0
  * Add rotated, hflip, and vflip options
  * Update FontAwesome and Material design icons
  * Rotate icons by static angle i.e. 90, 180 etc
  * PR: Update FontAwesome and Material design icons
  * PR: Add rotated, hflip, and vflip options
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.7:
  * Issue 113 - Corrupted icons with PyQt 5.12
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.6:
  * Too many changes to enumerate, see CHANGELOG.md
- Run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Aug 20 2018 dmueller@suse.com
- use singlespec'ed magic requires
* Sun Aug 19 2018 stefan.bruens@rwth-aachen.de
- Fix Requires:, refer to python2 packages from python2 package
- Remove erroneously distributed __pycache__ file from sources
- Spec cleanup:
  * drop %%defattr
  * use %%license for LICENSE
* Fri Jul 21 2017 sebix+novell.com@sebix.at
- license is packaged, remove it from sources
* Thu Oct 13 2016 toddrme2178@gmail.com
- Initial version
